local mod = HideBlizzard:NewModule('Pet', 'AceEvent-3.0')
mod.modName = 'Pet'

local options = {
	petactionbar = {
		type = 'toggle',
		name = 'Pet Action Bar',
		desc = 'Hide the pet action bar frame.',
		get = function() return mod.db.profile.petactionbar end,
		set = function(info, v)
			mod.db.profile.petactionbar = v
			if v then
				mod:EnablePetActionBar()
			else
				mod:DisablePetActionBar()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet end,
	},
	petcastbar = {
		type = 'toggle',
		name = 'Pet Cast Bar',
		desc = 'Hide the pet cast bar frame.',
		get = function() return mod.db.profile.petcastbar end,
		set = function(info, v)
			mod.db.profile.petcastbar = v
			if v then
				mod:EnablePetCastBar()
			else
				mod:DisablePetCastBar()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet end,
	},
	petunitframe = {
		type = 'toggle',
		name = 'Pet Unit Frame',
		desc = 'Hide the pet unit frame.',
		get = function() return mod.db.profile.petunitframe end,
		set = function(info, v)
			mod.db.profile.petunitframe = v
			if v then
				mod:EnablePetUnitFrame()
			else
				mod:DisablePetUnitFrame()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet end,
	},
}

local defaults = {
	profile = {
		petactionbar = false,
		petcastbar = false,
		petunitframe = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Pet', defaults)
end

function mod:OnEnable()
	self:UpdateFrames()
end

function mod:OnDisable()
	self:DisablePetActionBar()
	self:DisablePetCastBar()
	self:DisablePetUnitFrame()
end

function mod:UpdateFrames()
	if mod.db.profile.petactionbar == true then
		self:EnablePetActionBar()
	else
		self:DisablePetActionBar()
	end
	if mod.db.profile.petcastbar == true then
		self:EnablePetCastBar()
	else
		self:DisablePetCastBar()
	end
	if mod.db.profile.petunitframe == true then
		self:EnablePetUnitFrame()
	else
		self:DisablePetUnitFrame()
	end
end

function mod:EnablePetActionBar()
	PetActionBarFrame:UnregisterAllEvents()
	PetActionBarFrame:Hide()
end

function mod:DisablePetActionBar()
	if UnitExists('pet') then
		PetActionBarFrame:Show()
	end
	PetActionBarFrame:RegisterEvent('PLAYER_CONTROL_LOST')
	PetActionBarFrame:RegisterEvent('PLAYER_CONTROL_GAINED')
	PetActionBarFrame:RegisterEvent('PLAYER_FARSIGHT_FOCUS_CHANGED')
	PetActionBarFrame:RegisterEvent('UNIT_PET')
	PetActionBarFrame:RegisterEvent('UNIT_FLAGS')
	PetActionBarFrame:RegisterEvent('UNIT_AURA')
	PetActionBarFrame:RegisterEvent('PET_BAR_UPDATE')
	PetActionBarFrame:RegisterEvent('PET_BAR_UPDATE_COOLDOWN')
	PetActionBarFrame:RegisterEvent('PET_BAR_SHOWGRID')
	PetActionBarFrame:RegisterEvent('PET_BAR_HIDEGRID')
	PetActionBarFrame:RegisterEvent('PET_BAR_HIDE')
end

function mod:EnablePetCastBar()
	PetCastingBarFrame:UnregisterAllEvents()
	PetCastingBarFrame:Hide()
end

function mod:DisablePetCastBar()
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_START')
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_STOP')
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_FAILED')
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_INTERRUPTED')
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_DELAYED')
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_START')
	PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_UPDATE')
	PetCastingBarFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
	PetCastingBarFrame:RegisterEvent('UNIT_PET')
end

function mod:EnablePetUnitFrame()
	PetFrame:UnregisterAllEvents()
	PetFrame:Hide()
	PetFrame.Show = function() end
end

function mod:DisablePetUnitFrame()
	if UnitExists('pet') then
		PetFrame.Show = nil
		PetFrame:Show()
	end
	PetFrame:RegisterEvent('UNIT_PET')
	PetFrame:RegisterEvent('UNIT_COMBAT')
	PetFrame:RegisterEvent('UNIT_AURA')
	PetFrame:RegisterEvent('PET_ATTACK_START')
	PetFrame:RegisterEvent('PET_ATTACK_STOP')
	PetFrame:RegisterEvent('UNIT_HAPPINESS')
	PetFrame:RegisterEvent('PET_UI_UPDATE')
	PetFrame:RegisterEvent('PET_RENAMEABLE')
end

function mod:Info()
	return 'Hides pet related frames.'
end

function mod:GetOptions()
	return options
end