local mod = HideBlizzard:NewModule('SpecialFrames')
mod.modName = 'Special Frames'

local options = {
	minimap = {
		type = 'toggle',
		name = 'Minimap',
		desc = 'Hide the minimap frame.',
		get = function() return mod.db.profile.minimap end,
		set = function(info, v)
			mod.db.profile.minimap = v
			if v then
				mod:EnableMinimap()
			else
				mod:DisableMinimap()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.SpecialFrames end,
	},
	tooltip = {
		type = 'toggle',
		name = 'Tooltip',
		desc = 'Hide the tooltip frame.',
		get = function() return mod.db.profile.tooltip end,
		set = function(info, v)
			mod.db.profile.tooltip = v
			if v then
				mod:EnableTooltip()
			else
				mod:DisableTooltip()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.SpecialFrames end,
	},
}

local defaults = {
	profile = {
		minimap = false,
		tooltip = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Special Frames', defaults)
end

function mod:OnEnable()
	self:UpdateFrames()
end

function mod:OnDisable()
	self:DisableMinimap()
	self:DisableTooltip()
end

function mod:UpdateFrames()
	if mod.db.profile.minimap == true then
		self:EnableMinimap()
	else
		self:DisableMinimap()
	end
	if mod.db.profile.tooltip == true then
		self:EnableTooltip()
	else
		self:DisableTooltip()
	end
end

function mod:EnableMinimap()
	MinimapCluster:Hide()
end

function mod:DisableMinimap()
	MinimapCluster:Show()
end

local tooltipAddOns = {
	'CowTip',
	'lolTip',
	'RantTooltip',
	'TinyTip',
	'Tipsy',
	'TipTac',
	'TipTop',
}

function mod:EnableTooltip()
	hooksecurefunc('GameTooltip_SetDefaultAnchor', function(tooltip, parent)
		for tooltipAddOns in pairs(tooltipAddOns) do
			if IsAddOnLoaded(tooltipAddOns) then
				return
			else
				tooltip:SetOwner(parent, 'ANCHOR_NONE')
				tooltip:Hide()
			end
		end
	end)
end

function mod:DisableTooltip()
	hooksecurefunc('GameTooltip_SetDefaultAnchor', function(tooltip, parent)
		for tooltipAddOns in pairs(tooltipAddOns) do
			if IsAddOnLoaded(tooltipAddOns) then
				return
			else
				tooltip:SetOwner(parent, 'ANCHOR_NONE')
				tooltip:SetPoint('BOTTOMRIGHT', 'UIParent', 'BOTTOMRIGHT', -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y)
			end
		end
	end)
end

function mod:Info()
	return 'Hides various special ui frames.'
end

function mod:GetOptions()
	return options
end